@@ -89,9 +89,6 @@ gboolean pyg_error_check      (GError     **error);
 int      pygobject_constructv (PyGObject   *self,
                                guint        n_parameters,
                                GParameter  *parameters);
-int      pygobject_construct  (PyGObject   *self,
-                               const char  *first_property_name,
-                               ...);
 
 PyObject *pyg_integer_richcompare(PyObject *v,
                                   PyObject *w,
@@ -187,7 +184,7 @@ typedef struct {
 
 extern PyTypeObject PyGFlags_Type;
 
-#define PyGFlags_Check(x) (g_type_is_a(((PyGFlags*)x)->gtype, G_TYPE_FLAGS))
+#define PyGFlags_Check(x) (PyObject_IsInstance((PyObject *)x, (PyObject *)&PyGFlags_Type) && g_type_is_a(((PyGFlags*)x)->gtype, G_TYPE_FLAGS))
 
 extern PyObject * pyg_flags_add        (PyObject *   module,
 					const char * type_name,
@@ -197,7 +194,7 @@ extern PyObject * pyg_flags_from_gtype (GType        gtype,
 					int          value);
 
 /* pygenum */
-#define PyGEnum_Check(x) (g_type_is_a(((PyGFlags*)x)->gtype, G_TYPE_ENUM))
+#define PyGEnum_Check(x) (PyObject_IsInstance((PyObject *)x, (PyObject *)&PyGEnum_Type) && g_type_is_a(((PyGFlags*)x)->gtype, G_TYPE_ENUM))
 
 typedef struct {
 	PYGLIB_PyLongObject parent;
