@@ -9,10 +9,7 @@
 
 G_BEGIN_DECLS
 
-/* This is deprecated, don't use */
-#define PYGIL_API_IS_BUGGY FALSE
-
-  /* PyGClosure is a _private_ structure */
+/* PyGClosure is a _private_ structure */
 typedef void (* PyClosureExceptionHandler) (GValue *ret, guint n_param_values, const GValue *params);
 typedef struct _PyGClosure PyGClosure;
 typedef struct _PyGObjectData PyGObjectData;
@@ -92,8 +89,6 @@ struct _PyGObject_Functions {
     void (* register_class)(PyObject *dict, const gchar *class_name,
 			    GType gtype, PyTypeObject *type, PyObject *bases);
     void (* register_wrapper)(PyObject *self);
-    void (* register_sinkfunc)(GType type,
-			       void (* sinkfunc)(GObject *object));
     PyTypeObject *(* lookup_class)(GType type);
     PyObject *(* newgobj)(GObject *obj);
 
@@ -182,13 +177,6 @@ struct _PyGObject_Functions {
     void      (*register_class_init) (GType gtype, PyGClassInitFunc class_init);
     void      (*register_interface_info) (GType gtype, const GInterfaceInfo *info);
     void      (*closure_set_exception_handler) (GClosure *closure, PyClosureExceptionHandler handler);
-    int       (*pygobject_constructv) (PyGObject  *self,
-                                       guint       n_parameters,
-                                       GParameter *parameters);
-    int       (*pygobject_construct) (PyGObject  *self,
-                                      const char *first_property_name,
-                                      ...);
-    void      (*set_object_has_new_constructor) (GType type);
 
     void      (*add_warning_redirection) (const char *domain,
                                           PyObject   *warning);
@@ -211,8 +199,6 @@ struct _PyGObject_Functions *_PyGObject_API;
 
 #define pygobject_register_class    (_PyGObject_API->register_class)
 #define pygobject_register_wrapper  (_PyGObject_API->register_wrapper)
-/* This is deprecated, sinkfuncs are not needed anymore */
-#define pygobject_register_sinkfunc (_PyGObject_API->register_sinkfunc)
 #define pygobject_lookup_class      (_PyGObject_API->lookup_class)
 #define pygobject_new               (_PyGObject_API->newgobj)
 #define pyg_closure_new             (_PyGObject_API->closure_new)
@@ -224,8 +210,6 @@ struct _PyGObject_Functions *_PyGObject_API;
 #define pyg_type_wrapper_new        (_PyGObject_API->type_wrapper_new)
 #define pyg_enum_get_value          (_PyGObject_API->enum_get_value)
 #define pyg_flags_get_value         (_PyGObject_API->flags_get_value)
-/* This is deprecated, call pyg_register_gtype_custom directly instead */
-#define pyg_register_boxed_custom   pyg_register_gtype_custom
 #define pyg_register_gtype_custom   (_PyGObject_API->register_gtype_custom)
 #define pyg_value_from_pyobject     (_PyGObject_API->value_from_pyobject)
 #define pyg_value_as_pyobject       (_PyGObject_API->value_as_pyobject)
@@ -259,9 +243,6 @@ struct _PyGObject_Functions *_PyGObject_API;
 #define pyg_gil_state_release       (_PyGObject_API->gil_state_release)
 #define pyg_register_class_init     (_PyGObject_API->register_class_init)
 #define pyg_register_interface_info (_PyGObject_API->register_interface_info)
-#define pygobject_construct         (_PyGObject_API->pygobject_construct)
-#define pygobject_constructv        (_PyGObject_API->pygobject_constructv)
-#define pyg_set_object_has_new_constructor (_PyGObject_API->set_object_has_new_constructor)
 #define pyg_add_warning_redirection   (_PyGObject_API->add_warning_redirection)
 #define pyg_disable_warning_redirections (_PyGObject_API->disable_warning_redirections)
 #define pyg_type_register_custom_callback (_PyGObject_API->type_register_custom)
@@ -375,8 +356,6 @@ pygobject_init(int req_major, int req_minor, int req_micro)
         PyObject *version;
 
         version = PyObject_GetAttrString(gobject, "pygobject_version");
-        if (!version)
-            version = PyObject_GetAttrString(gobject, "pygtk_version");
         if (!version) {
             PyErr_SetString(PyExc_ImportError,
                             "could not import gobject (version too old)");
@@ -406,18 +385,6 @@ pygobject_init(int req_major, int req_minor, int req_micro)
     return gobject;
 }
 
-/* deprecated macro, use pygobject_init() instead. */
-#define init_pygobject() G_STMT_START {         \
-    if (!pygobject_init(-1, -1, -1))            \
-        return;                                 \
-} G_STMT_END
-
-/* deprecated macro, use pygobject_init() instead. */
-#define init_pygobject_check(req_major, req_minor, req_micro) G_STMT_START {    \
-    if (!pygobject_init(req_major, req_minor, req_micro))                       \
-        return;                                                                 \
-} G_STMT_END
-
 /**
  * PYLIST_FROMGLIBLIST:
  * @type: the type of the GLib list e.g. #GList or #GSList
